@@ -2,12 +2,11 @@ package Mojolicious::Plugin::SimpleSlides;
 
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 $VERSION = eval $VERSION;
 
 use File::Spec;
-use File::Basename ();
-use File::ShareDir ();
+use File::Share ();
 
 has 'base_href';
 
@@ -25,13 +24,10 @@ has 'layout' => 'simple_slides';
 has 'slides';
 
 has 'static_path' => sub {
-  my $local = File::Spec->catdir(File::Basename::dirname(__FILE__), 'SimpleSlides', 'public');
-  return $local if -d $local;
-
-  my $share = File::ShareDir::dist_dir('Mojolicious-Plugin-SimpleSlides');
+  my $share = eval { File::Spec->catdir(File::Share::dist_dir('Mojolicious-Plugin-SimpleSlides'), 'public') };
   return $share if -d $share;
 
-  warn "Cannot find static content for Mojolicious::Plugin::SimpleSlides, (checked $local and $share). The bundled javascript and css files will not work correctly.\n";
+  warn "Cannot find static content for Mojolicious::Plugin::SimpleSlides, (checked $share). The bundled javascript and css files will not work correctly.\n";
 };
 
 sub register {
@@ -72,7 +68,7 @@ sub register {
     shift->tag('pre' => class => 'code-line' => @_);
   });
 
-  $app->routes->any( 
+  $app->routes->any(
     '/:slide',
     { slide => $plugin->first_slide },
     [ slide => qr/\b\d+\b/ ],
@@ -103,7 +99,7 @@ sub next_slide {
 sub _action {
   my $c = shift;
   my $plugin = $c->simple_slides;
-  my $slide = $plugin->template_for_slide($c->stash( 'slide' )) 
+  my $slide = $plugin->template_for_slide($c->stash( 'slide' ))
     or return $c->reply->not_found;
   $c->layout( $plugin->layout );
   $c->render( $slide ) || $c->reply->not_found;
@@ -111,7 +107,7 @@ sub _action {
 
 # helpers
 
-sub _column { 
+sub _column {
   my $c = shift;
   my $plugin = $c->simple_slides;
   my $content = pop || return;
@@ -128,21 +124,21 @@ sub _column {
   if ( my $align = delete $args{align} || $plugin->column_align ) {
     $style .= "vertical-align: $align;";
   }
- 
-  return $c->render( 
-    partial => 1, 
+
+  return $c->render(
+    partial => 1,
     'columns.style' => $style,
-    'columns.column' => $content, 
+    'columns.column' => $content,
     template => $plugin->column_template,
   );
 }
 
-sub _columns { 
+sub _columns {
   my $c = shift;
   return unless @_;
   my $content = shift->();
-  return $c->render( 
-    partial => 1, 
+  return $c->render(
+    partial => 1,
     'columns.content' => $content,
     template => $c->simple_slides->columns_template,
   );
@@ -191,7 +187,7 @@ __DATA__
 
 @@ simple_slides_column.html.ep
 % my @tag = qw/div class column/;
-% if ( my $style = stash 'columns.style' ) { push @tag, style => $style } 
+% if ( my $style = stash 'columns.style' ) { push @tag, style => $style }
 %= tag @tag, begin
   %= stash 'columns.column'
 % end
